@@ -2,7 +2,7 @@
 print_lol() which prints lists that may or may not include nested lists."""
 
 
-def print_lol(the_list,level):
+def print_lol(the_list,level=0):
     """This function takes a proportional argument called "the list", which is any
     Python list (of, possibly, nested lists). Each data item in the provided list
     is (recursively) printed to the screen on it's own line. A second argument
